import json
import numpy as np

# Joint ChiEff ChiP
with open('gaussian-chiEff-chiP-samples.json','r') as jf:
    samps = json.load(jf)
mu_eff = np.array(samps['mu_eff'])
sig_eff = np.array(samps['sigma_eff'])
mu_p = np.array(samps['mu_p'])
sig_p = np.array(samps['sigma_p'])

# ChiEff-ChiP without 190521 and 190412
with open('gaussian-chiEff-chiP-samples_no_190521A_190412.json','r') as jf_subset:
    samps_subset = json.load(jf_subset)
mu_p_subset = np.array(samps_subset['mu_p'])
sig_p_subset = np.array(samps_subset['sigma_p'])

# ChiEff with variable minimum
with open('gaussian-chiEff-variable-chiMin-samples.json','r') as jf_variable:
    samps_variable = json.load(jf_variable)
mu_eff_variable = np.array(samps_variable['mu_eff'])
sig_eff_variable = np.array(samps_variable['sigma_eff'])
min_eff_variable = np.array(samps_variable['chi_eff_min'])

with open('./gaussian-spin-macros.tex','w') as macrofile:

    # Total number of posterior samples in chiEff-chiP analysis
    macrofile.write("% Number of posterior samples plotted \n")
    macrofile.write("\\newcommand{{\\NumberOfGaussianSpinSamples}}{{\\ensuremath{{{0:.0f}}}}}\n".format(mu_p.size))

    # Number of samples at "undiscernably small" values of chi_p
    macrofile.write("% Number of posterior samples with mu_p<0.05 and sig_p<0.05 \n")
    nSmall = mu_p[(mu_p<=0.05)*(sig_p<=0.05)].size
    macrofile.write("\\newcommand{{\\NumberOfSmallChiPSamples}}{{\\ensuremath{{{0:.0f}}}}}\n".format(nSmall))

    # *Percentage* of samples at "undiscernably small" values
    macrofile.write("% Fraction of posterior samples with mu_p<0.05 and sig_p<0.05 \n")
    print(max(nSmall,1))
    macrofile.write("\\newcommand{{\\FractionOfSmallChiPSamples}}{{\\ensuremath{{{0:.2f}\%}}}}\n".format(100.*max(nSmall,1)/float(mu_p.size)))

    # Percentage of "undiscernably small" samples with high-spin events removed
    macrofile.write("% Fraction of posterior samples with mu_p<0.05 and sig_p<0.05 with 190521A and 190412 removed\n")
    nSmall_subset = mu_p_subset[(mu_p_subset<=0.05)*(sig_p_subset<=0.05)].size
    print(max(nSmall_subset,1))
    macrofile.write("\\newcommand{{\\FractionOfSmallChiPSamplesReducedSample}}{{\\ensuremath{{{0:.2f}\%}}}}\n".format(100.*max(nSmall_subset,1)/float(mu_p_subset.size)))

    # 5%, 50%, and 95% credible intervals on mu_effective
    mu_eff_05 = np.quantile(mu_eff,0.05)
    mu_eff_50 = np.quantile(mu_eff,0.50)
    mu_eff_95 = np.quantile(mu_eff,0.95)
    macrofile.write("\n% Median mu_eff\n")
    macrofile.write("\\newcommand{{\\medianMuEff}}{{\\ensuremath{{{0:.2f}}}}}\n".format(mu_eff_50))
    macrofile.write("% Upper error on mu_eff (90\% uncertainty)\n")
    macrofile.write("\\newcommand{{\\errorMuEffHigh}}{{\\ensuremath{{{0:.2f}}}}}\n".format(mu_eff_95-mu_eff_50))
    macrofile.write("% Lower error on mu_eff (90\% uncertainty)\n")
    macrofile.write("\\newcommand{{\\errorMuEffLow}}{{\\ensuremath{{{0:.2f}}}}}\n".format(mu_eff_50-mu_eff_05))

    # 5%, 50%, and 95% credible intervals on sigma_effective
    sigma_eff_05 = np.quantile(sig_eff,0.05)
    sigma_eff_50 = np.quantile(sig_eff,0.50)
    sigma_eff_95 = np.quantile(sig_eff,0.95)
    macrofile.write("\n% Median sigma_eff\n")
    macrofile.write("\\newcommand{{\\medianSigmaEff}}{{\\ensuremath{{{0:.2f}}}}}\n".format(sigma_eff_50))
    macrofile.write("% Upper error on sigma_eff (90\% uncertainty)\n")
    macrofile.write("\\newcommand{{\\errorSigmaEffHigh}}{{\\ensuremath{{{0:.2f}}}}}\n".format(sigma_eff_95-sigma_eff_50))
    macrofile.write("% Lower error on sigma_eff (90\% uncertainty)\n")
    macrofile.write("\\newcommand{{\\errorSigmaEffLow}}{{\\ensuremath{{{0:.2f}}}}}\n".format(sigma_eff_50-sigma_eff_05))

    # Percentage of samples with minimum chi-effective <0
    macrofile.write("\n")
    macrofile.write("% In variable chiMin test, percentage of samples with chi_eff_min<0\n")
    percent_negative = 100.*min_eff_variable[min_eff_variable<0.].size/float(min_eff_variable.size)
    macrofile.write("\\newcommand{{\\percentMinChiLessThanZero}}{{\\ensuremath{{{0:.0f}\%}}}}\n".format(percent_negative))


